# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.product import product_pb2 as services_dot_product_dot_product__pb2
from common.api.services.shop import shop_pb2 as services_dot_shop_dot_shop__pb2


class ShopServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/social.shop.ShopService/Ping',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Pong.FromString,
                )
        self.Upsert = channel.unary_unary(
                '/social.shop.ShopService/Upsert',
                request_serializer=services_dot_shop_dot_shop__pb2.UpsertRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.InventoryInCart.FromString,
                )
        self.Delete = channel.unary_unary(
                '/social.shop.ShopService/Delete',
                request_serializer=services_dot_product_dot_product__pb2.Product.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.Get = channel.unary_unary(
                '/social.shop.ShopService/Get',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.Cart.FromString,
                )
        self.CheckOut = channel.unary_unary(
                '/social.shop.ShopService/CheckOut',
                request_serializer=services_dot_shop_dot_shop__pb2.CheckoutRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.Order.FromString,
                )
        self.CheckOutV2 = channel.unary_unary(
                '/social.shop.ShopService/CheckOutV2',
                request_serializer=services_dot_shop_dot_shop__pb2.CheckoutRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.CheckoutResponse.FromString,
                )
        self.PayOrder = channel.unary_unary(
                '/social.shop.ShopService/PayOrder',
                request_serializer=services_dot_shop_dot_shop__pb2.PayOrderRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.PayOrderResponse.FromString,
                )
        self.GetOrder = channel.unary_unary(
                '/social.shop.ShopService/GetOrder',
                request_serializer=services_dot_shop_dot_shop__pb2.Order.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.Order.FromString,
                )
        self.GetAllOrders = channel.unary_unary(
                '/social.shop.ShopService/GetAllOrders',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.OrderList.FromString,
                )
        self.GetOrdersByStatus = channel.unary_unary(
                '/social.shop.ShopService/GetOrdersByStatus',
                request_serializer=services_dot_shop_dot_shop__pb2.GetOrdersByStatusRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.OrderList.FromString,
                )
        self.GetPayment = channel.unary_unary(
                '/social.shop.ShopService/GetPayment',
                request_serializer=services_dot_shop_dot_shop__pb2.Payment.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.Payment.FromString,
                )
        self.GetAllPayments = channel.unary_unary(
                '/social.shop.ShopService/GetAllPayments',
                request_serializer=services_dot_common_dot_common__pb2.Pagination.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.PaymentList.FromString,
                )
        self.GetAllGates = channel.unary_unary(
                '/social.shop.ShopService/GetAllGates',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.GateList.FromString,
                )
        self.Deposit = channel.unary_unary(
                '/social.shop.ShopService/Deposit',
                request_serializer=services_dot_shop_dot_shop__pb2.DepositRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.DepositResponse.FromString,
                )
        self.GetWalletBalance = channel.unary_unary(
                '/social.shop.ShopService/GetWalletBalance',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.WalletBalance.FromString,
                )
        self.GetWalletHistory = channel.unary_unary(
                '/social.shop.ShopService/GetWalletHistory',
                request_serializer=services_dot_common_dot_common__pb2.Pagination.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.WalletHistoryList.FromString,
                )
        self.Withdrawal = channel.unary_unary(
                '/social.shop.ShopService/Withdrawal',
                request_serializer=services_dot_shop_dot_shop__pb2.WithdrawalRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.WithdrawalResponse.FromString,
                )
        self.GetDiscount = channel.unary_unary(
                '/social.shop.ShopService/GetDiscount',
                request_serializer=services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.Discount.FromString,
                )
        self.GetInventoryInCart = channel.unary_unary(
                '/social.shop.ShopService/GetInventoryInCart',
                request_serializer=services_dot_shop_dot_shop__pb2.InventoryInCartRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.InventoryInCartList.FromString,
                )
        self.OwnerSetProductShippingStatus = channel.unary_unary(
                '/social.shop.ShopService/OwnerSetProductShippingStatus',
                request_serializer=services_dot_shop_dot_shop__pb2.SetProductStatusRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.OwnerBulkSetProductShippingStatus = channel.unary_unary(
                '/social.shop.ShopService/OwnerBulkSetProductShippingStatus',
                request_serializer=services_dot_shop_dot_shop__pb2.BulkSetProductStatusRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.OwnerGetOrdersByStatus = channel.unary_unary(
                '/social.shop.ShopService/OwnerGetOrdersByStatus',
                request_serializer=services_dot_shop_dot_shop__pb2.GetOrdersByStatusRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.OrderList.FromString,
                )
        self.AdminVerifyDeliveryCode = channel.unary_unary(
                '/social.shop.ShopService/AdminVerifyDeliveryCode',
                request_serializer=services_dot_shop_dot_shop__pb2.VerifyDeliveryCodeRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.UpsertSellerSchedule = channel.unary_unary(
                '/social.shop.ShopService/UpsertSellerSchedule',
                request_serializer=services_dot_shop_dot_shop__pb2.SellerSchedule.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.GetSellerSchedule = channel.unary_unary(
                '/social.shop.ShopService/GetSellerSchedule',
                request_serializer=services_dot_shop_dot_shop__pb2.GetSellerScheduleRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.SellerSchedule.FromString,
                )
        self.GetPostCapacity = channel.unary_unary(
                '/social.shop.ShopService/GetPostCapacity',
                request_serializer=services_dot_shop_dot_shop__pb2.GetPostCapacityRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.PostCapacityList.FromString,
                )
        self.GetScheduleForCart = channel.unary_unary(
                '/social.shop.ShopService/GetScheduleForCart',
                request_serializer=services_dot_shop_dot_shop__pb2.GetScheduleForCartRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.ScheduleForCart.FromString,
                )
        self.GetPeriods = channel.unary_unary(
                '/social.shop.ShopService/GetPeriods',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.Periods.FromString,
                )
        self.AdminCreateDiscount = channel.unary_unary(
                '/social.shop.ShopService/AdminCreateDiscount',
                request_serializer=services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.Discount.FromString,
                )
        self.AdminUpdateDiscount = channel.unary_unary(
                '/social.shop.ShopService/AdminUpdateDiscount',
                request_serializer=services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.Discount.FromString,
                )
        self.AdminDeleteDiscount = channel.unary_unary(
                '/social.shop.ShopService/AdminDeleteDiscount',
                request_serializer=services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminGetAllDiscount = channel.unary_unary(
                '/social.shop.ShopService/AdminGetAllDiscount',
                request_serializer=services_dot_common_dot_common__pb2.Pagination.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.DiscountList.FromString,
                )
        self.AdminApproveOrRejectWithdrawal = channel.unary_unary(
                '/social.shop.ShopService/AdminApproveOrRejectWithdrawal',
                request_serializer=services_dot_shop_dot_shop__pb2.ApproveWithdrawalRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminGetAllWithdrawalsRequests = channel.unary_unary(
                '/social.shop.ShopService/AdminGetAllWithdrawalsRequests',
                request_serializer=services_dot_shop_dot_shop__pb2.GetAllWithdrawalsRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.WithdrawalList.FromString,
                )
        self.AdminToggleGateway = channel.unary_unary(
                '/social.shop.ShopService/AdminToggleGateway',
                request_serializer=services_dot_shop_dot_shop__pb2.ToggleGatewayRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminGetCompanyWalletHistory = channel.unary_unary(
                '/social.shop.ShopService/AdminGetCompanyWalletHistory',
                request_serializer=services_dot_common_dot_common__pb2.Pagination.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.CompanyWalletHistoryList.FromString,
                )
        self.AdminGetCompanyWalletBalance = channel.unary_unary(
                '/social.shop.ShopService/AdminGetCompanyWalletBalance',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.WalletBalance.FromString,
                )
        self.AdminSetOrderShippingStatus = channel.unary_unary(
                '/social.shop.ShopService/AdminSetOrderShippingStatus',
                request_serializer=services_dot_shop_dot_shop__pb2.SetOrderStatusRequest.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.Order.FromString,
                )
        self.AdminGetAllOrders = channel.unary_unary(
                '/social.shop.ShopService/AdminGetAllOrders',
                request_serializer=services_dot_common_dot_common__pb2.Pagination.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.OrderList.FromString,
                )
        self.AdminUpsertCompanySchedule = channel.unary_unary(
                '/social.shop.ShopService/AdminUpsertCompanySchedule',
                request_serializer=services_dot_shop_dot_shop__pb2.CompanySchedule.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminGetCompanySchedule = channel.unary_unary(
                '/social.shop.ShopService/AdminGetCompanySchedule',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_shop_dot_shop__pb2.CompanySchedule.FromString,
                )
        self.AdminUpsertPostCapacity = channel.unary_unary(
                '/social.shop.ShopService/AdminUpsertPostCapacity',
                request_serializer=services_dot_shop_dot_shop__pb2.PostCapacity.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminSetProductShippingStatus = channel.unary_unary(
                '/social.shop.ShopService/AdminSetProductShippingStatus',
                request_serializer=services_dot_shop_dot_shop__pb2.SetProductStatusRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminBulkSetProductShippingStatus = channel.unary_unary(
                '/social.shop.ShopService/AdminBulkSetProductShippingStatus',
                request_serializer=services_dot_shop_dot_shop__pb2.BulkSetProductStatusRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )


class ShopServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Upsert(self, request, context):
        """Order & User methods
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckOut(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckOutV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PayOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllOrders(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrdersByStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPayment(self, request, context):
        """Wallet
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllPayments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllGates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deposit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWalletBalance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWalletHistory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Withdrawal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDiscount(self, request, context):
        """Other
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryInCart(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OwnerSetProductShippingStatus(self, request, context):
        """Product Owner
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OwnerBulkSetProductShippingStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OwnerGetOrdersByStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminVerifyDeliveryCode(self, request, context):
        """PostMan
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertSellerSchedule(self, request, context):
        """schedule
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSellerSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPostCapacity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScheduleForCart(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPeriods(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminCreateDiscount(self, request, context):
        """Admin Discount
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminUpdateDiscount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminDeleteDiscount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminGetAllDiscount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminApproveOrRejectWithdrawal(self, request, context):
        """Admin Wallet
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminGetAllWithdrawalsRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminToggleGateway(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminGetCompanyWalletHistory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminGetCompanyWalletBalance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminSetOrderShippingStatus(self, request, context):
        """Admin Order
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminGetAllOrders(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminUpsertCompanySchedule(self, request, context):
        """Admin Schedule
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminGetCompanySchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminUpsertPostCapacity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminSetProductShippingStatus(self, request, context):
        """Admin Product Shipping
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminBulkSetProductShippingStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ShopServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Pong.SerializeToString,
            ),
            'Upsert': grpc.unary_unary_rpc_method_handler(
                    servicer.Upsert,
                    request_deserializer=services_dot_shop_dot_shop__pb2.UpsertRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.InventoryInCart.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=services_dot_product_dot_product__pb2.Product.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.Cart.SerializeToString,
            ),
            'CheckOut': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckOut,
                    request_deserializer=services_dot_shop_dot_shop__pb2.CheckoutRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.Order.SerializeToString,
            ),
            'CheckOutV2': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckOutV2,
                    request_deserializer=services_dot_shop_dot_shop__pb2.CheckoutRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.CheckoutResponse.SerializeToString,
            ),
            'PayOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.PayOrder,
                    request_deserializer=services_dot_shop_dot_shop__pb2.PayOrderRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.PayOrderResponse.SerializeToString,
            ),
            'GetOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrder,
                    request_deserializer=services_dot_shop_dot_shop__pb2.Order.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.Order.SerializeToString,
            ),
            'GetAllOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllOrders,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.OrderList.SerializeToString,
            ),
            'GetOrdersByStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrdersByStatus,
                    request_deserializer=services_dot_shop_dot_shop__pb2.GetOrdersByStatusRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.OrderList.SerializeToString,
            ),
            'GetPayment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPayment,
                    request_deserializer=services_dot_shop_dot_shop__pb2.Payment.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.Payment.SerializeToString,
            ),
            'GetAllPayments': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllPayments,
                    request_deserializer=services_dot_common_dot_common__pb2.Pagination.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.PaymentList.SerializeToString,
            ),
            'GetAllGates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllGates,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.GateList.SerializeToString,
            ),
            'Deposit': grpc.unary_unary_rpc_method_handler(
                    servicer.Deposit,
                    request_deserializer=services_dot_shop_dot_shop__pb2.DepositRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.DepositResponse.SerializeToString,
            ),
            'GetWalletBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWalletBalance,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.WalletBalance.SerializeToString,
            ),
            'GetWalletHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWalletHistory,
                    request_deserializer=services_dot_common_dot_common__pb2.Pagination.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.WalletHistoryList.SerializeToString,
            ),
            'Withdrawal': grpc.unary_unary_rpc_method_handler(
                    servicer.Withdrawal,
                    request_deserializer=services_dot_shop_dot_shop__pb2.WithdrawalRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.WithdrawalResponse.SerializeToString,
            ),
            'GetDiscount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDiscount,
                    request_deserializer=services_dot_shop_dot_shop__pb2.Discount.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
            ),
            'GetInventoryInCart': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryInCart,
                    request_deserializer=services_dot_shop_dot_shop__pb2.InventoryInCartRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.InventoryInCartList.SerializeToString,
            ),
            'OwnerSetProductShippingStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.OwnerSetProductShippingStatus,
                    request_deserializer=services_dot_shop_dot_shop__pb2.SetProductStatusRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'OwnerBulkSetProductShippingStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.OwnerBulkSetProductShippingStatus,
                    request_deserializer=services_dot_shop_dot_shop__pb2.BulkSetProductStatusRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'OwnerGetOrdersByStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.OwnerGetOrdersByStatus,
                    request_deserializer=services_dot_shop_dot_shop__pb2.GetOrdersByStatusRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.OrderList.SerializeToString,
            ),
            'AdminVerifyDeliveryCode': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminVerifyDeliveryCode,
                    request_deserializer=services_dot_shop_dot_shop__pb2.VerifyDeliveryCodeRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'UpsertSellerSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertSellerSchedule,
                    request_deserializer=services_dot_shop_dot_shop__pb2.SellerSchedule.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'GetSellerSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSellerSchedule,
                    request_deserializer=services_dot_shop_dot_shop__pb2.GetSellerScheduleRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.SellerSchedule.SerializeToString,
            ),
            'GetPostCapacity': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPostCapacity,
                    request_deserializer=services_dot_shop_dot_shop__pb2.GetPostCapacityRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.PostCapacityList.SerializeToString,
            ),
            'GetScheduleForCart': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScheduleForCart,
                    request_deserializer=services_dot_shop_dot_shop__pb2.GetScheduleForCartRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.ScheduleForCart.SerializeToString,
            ),
            'GetPeriods': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPeriods,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.Periods.SerializeToString,
            ),
            'AdminCreateDiscount': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminCreateDiscount,
                    request_deserializer=services_dot_shop_dot_shop__pb2.Discount.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
            ),
            'AdminUpdateDiscount': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminUpdateDiscount,
                    request_deserializer=services_dot_shop_dot_shop__pb2.Discount.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
            ),
            'AdminDeleteDiscount': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminDeleteDiscount,
                    request_deserializer=services_dot_shop_dot_shop__pb2.Discount.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminGetAllDiscount': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminGetAllDiscount,
                    request_deserializer=services_dot_common_dot_common__pb2.Pagination.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.DiscountList.SerializeToString,
            ),
            'AdminApproveOrRejectWithdrawal': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminApproveOrRejectWithdrawal,
                    request_deserializer=services_dot_shop_dot_shop__pb2.ApproveWithdrawalRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminGetAllWithdrawalsRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminGetAllWithdrawalsRequests,
                    request_deserializer=services_dot_shop_dot_shop__pb2.GetAllWithdrawalsRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.WithdrawalList.SerializeToString,
            ),
            'AdminToggleGateway': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminToggleGateway,
                    request_deserializer=services_dot_shop_dot_shop__pb2.ToggleGatewayRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminGetCompanyWalletHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminGetCompanyWalletHistory,
                    request_deserializer=services_dot_common_dot_common__pb2.Pagination.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.CompanyWalletHistoryList.SerializeToString,
            ),
            'AdminGetCompanyWalletBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminGetCompanyWalletBalance,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.WalletBalance.SerializeToString,
            ),
            'AdminSetOrderShippingStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminSetOrderShippingStatus,
                    request_deserializer=services_dot_shop_dot_shop__pb2.SetOrderStatusRequest.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.Order.SerializeToString,
            ),
            'AdminGetAllOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminGetAllOrders,
                    request_deserializer=services_dot_common_dot_common__pb2.Pagination.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.OrderList.SerializeToString,
            ),
            'AdminUpsertCompanySchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminUpsertCompanySchedule,
                    request_deserializer=services_dot_shop_dot_shop__pb2.CompanySchedule.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminGetCompanySchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminGetCompanySchedule,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_shop_dot_shop__pb2.CompanySchedule.SerializeToString,
            ),
            'AdminUpsertPostCapacity': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminUpsertPostCapacity,
                    request_deserializer=services_dot_shop_dot_shop__pb2.PostCapacity.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminSetProductShippingStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminSetProductShippingStatus,
                    request_deserializer=services_dot_shop_dot_shop__pb2.SetProductStatusRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminBulkSetProductShippingStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminBulkSetProductShippingStatus,
                    request_deserializer=services_dot_shop_dot_shop__pb2.BulkSetProductStatusRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'social.shop.ShopService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ShopService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/Ping',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_common_dot_common__pb2.Pong.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Upsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/Upsert',
            services_dot_shop_dot_shop__pb2.UpsertRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.InventoryInCart.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/Delete',
            services_dot_product_dot_product__pb2.Product.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/Get',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_shop_dot_shop__pb2.Cart.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/CheckOut',
            services_dot_shop_dot_shop__pb2.CheckoutRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.Order.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckOutV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/CheckOutV2',
            services_dot_shop_dot_shop__pb2.CheckoutRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.CheckoutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PayOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/PayOrder',
            services_dot_shop_dot_shop__pb2.PayOrderRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.PayOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetOrder',
            services_dot_shop_dot_shop__pb2.Order.SerializeToString,
            services_dot_shop_dot_shop__pb2.Order.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetAllOrders',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_shop_dot_shop__pb2.OrderList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrdersByStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetOrdersByStatus',
            services_dot_shop_dot_shop__pb2.GetOrdersByStatusRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.OrderList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPayment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetPayment',
            services_dot_shop_dot_shop__pb2.Payment.SerializeToString,
            services_dot_shop_dot_shop__pb2.Payment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllPayments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetAllPayments',
            services_dot_common_dot_common__pb2.Pagination.SerializeToString,
            services_dot_shop_dot_shop__pb2.PaymentList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllGates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetAllGates',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_shop_dot_shop__pb2.GateList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deposit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/Deposit',
            services_dot_shop_dot_shop__pb2.DepositRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.DepositResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWalletBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetWalletBalance',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_shop_dot_shop__pb2.WalletBalance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWalletHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetWalletHistory',
            services_dot_common_dot_common__pb2.Pagination.SerializeToString,
            services_dot_shop_dot_shop__pb2.WalletHistoryList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Withdrawal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/Withdrawal',
            services_dot_shop_dot_shop__pb2.WithdrawalRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.WithdrawalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDiscount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetDiscount',
            services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
            services_dot_shop_dot_shop__pb2.Discount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryInCart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetInventoryInCart',
            services_dot_shop_dot_shop__pb2.InventoryInCartRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.InventoryInCartList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OwnerSetProductShippingStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/OwnerSetProductShippingStatus',
            services_dot_shop_dot_shop__pb2.SetProductStatusRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OwnerBulkSetProductShippingStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/OwnerBulkSetProductShippingStatus',
            services_dot_shop_dot_shop__pb2.BulkSetProductStatusRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OwnerGetOrdersByStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/OwnerGetOrdersByStatus',
            services_dot_shop_dot_shop__pb2.GetOrdersByStatusRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.OrderList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminVerifyDeliveryCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminVerifyDeliveryCode',
            services_dot_shop_dot_shop__pb2.VerifyDeliveryCodeRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertSellerSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/UpsertSellerSchedule',
            services_dot_shop_dot_shop__pb2.SellerSchedule.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSellerSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetSellerSchedule',
            services_dot_shop_dot_shop__pb2.GetSellerScheduleRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.SellerSchedule.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPostCapacity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetPostCapacity',
            services_dot_shop_dot_shop__pb2.GetPostCapacityRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.PostCapacityList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetScheduleForCart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetScheduleForCart',
            services_dot_shop_dot_shop__pb2.GetScheduleForCartRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.ScheduleForCart.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPeriods(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/GetPeriods',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_shop_dot_shop__pb2.Periods.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminCreateDiscount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminCreateDiscount',
            services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
            services_dot_shop_dot_shop__pb2.Discount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminUpdateDiscount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminUpdateDiscount',
            services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
            services_dot_shop_dot_shop__pb2.Discount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminDeleteDiscount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminDeleteDiscount',
            services_dot_shop_dot_shop__pb2.Discount.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminGetAllDiscount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminGetAllDiscount',
            services_dot_common_dot_common__pb2.Pagination.SerializeToString,
            services_dot_shop_dot_shop__pb2.DiscountList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminApproveOrRejectWithdrawal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminApproveOrRejectWithdrawal',
            services_dot_shop_dot_shop__pb2.ApproveWithdrawalRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminGetAllWithdrawalsRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminGetAllWithdrawalsRequests',
            services_dot_shop_dot_shop__pb2.GetAllWithdrawalsRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.WithdrawalList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminToggleGateway(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminToggleGateway',
            services_dot_shop_dot_shop__pb2.ToggleGatewayRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminGetCompanyWalletHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminGetCompanyWalletHistory',
            services_dot_common_dot_common__pb2.Pagination.SerializeToString,
            services_dot_shop_dot_shop__pb2.CompanyWalletHistoryList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminGetCompanyWalletBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminGetCompanyWalletBalance',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_shop_dot_shop__pb2.WalletBalance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminSetOrderShippingStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminSetOrderShippingStatus',
            services_dot_shop_dot_shop__pb2.SetOrderStatusRequest.SerializeToString,
            services_dot_shop_dot_shop__pb2.Order.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminGetAllOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminGetAllOrders',
            services_dot_common_dot_common__pb2.Pagination.SerializeToString,
            services_dot_shop_dot_shop__pb2.OrderList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminUpsertCompanySchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminUpsertCompanySchedule',
            services_dot_shop_dot_shop__pb2.CompanySchedule.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminGetCompanySchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminGetCompanySchedule',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_shop_dot_shop__pb2.CompanySchedule.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminUpsertPostCapacity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminUpsertPostCapacity',
            services_dot_shop_dot_shop__pb2.PostCapacity.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminSetProductShippingStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminSetProductShippingStatus',
            services_dot_shop_dot_shop__pb2.SetProductStatusRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminBulkSetProductShippingStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.shop.ShopService/AdminBulkSetProductShippingStatus',
            services_dot_shop_dot_shop__pb2.BulkSetProductStatusRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.stats import stats_pb2 as services_dot_stats_dot_stats__pb2


class StatsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/social.stats.StatsService/Ping',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Pong.FromString,
                )
        self.Increment = channel.unary_unary(
                '/social.stats.StatsService/Increment',
                request_serializer=services_dot_stats_dot_stats__pb2.Stat.SerializeToString,
                response_deserializer=services_dot_stats_dot_stats__pb2.IncrementResponse.FromString,
                )
        self.Decrement = channel.unary_unary(
                '/social.stats.StatsService/Decrement',
                request_serializer=services_dot_stats_dot_stats__pb2.Stat.SerializeToString,
                response_deserializer=services_dot_stats_dot_stats__pb2.DecrementResponse.FromString,
                )
        self.Count = channel.unary_unary(
                '/social.stats.StatsService/Count',
                request_serializer=services_dot_stats_dot_stats__pb2.Stat.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Int64Value.FromString,
                )
        self.GetActors = channel.unary_unary(
                '/social.stats.StatsService/GetActors',
                request_serializer=services_dot_stats_dot_stats__pb2.GetActorsRequest.SerializeToString,
                response_deserializer=services_dot_stats_dot_stats__pb2.GetActorsResponse.FromString,
                )


class StatsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Increment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Decrement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Count(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StatsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Pong.SerializeToString,
            ),
            'Increment': grpc.unary_unary_rpc_method_handler(
                    servicer.Increment,
                    request_deserializer=services_dot_stats_dot_stats__pb2.Stat.FromString,
                    response_serializer=services_dot_stats_dot_stats__pb2.IncrementResponse.SerializeToString,
            ),
            'Decrement': grpc.unary_unary_rpc_method_handler(
                    servicer.Decrement,
                    request_deserializer=services_dot_stats_dot_stats__pb2.Stat.FromString,
                    response_serializer=services_dot_stats_dot_stats__pb2.DecrementResponse.SerializeToString,
            ),
            'Count': grpc.unary_unary_rpc_method_handler(
                    servicer.Count,
                    request_deserializer=services_dot_stats_dot_stats__pb2.Stat.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Int64Value.SerializeToString,
            ),
            'GetActors': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActors,
                    request_deserializer=services_dot_stats_dot_stats__pb2.GetActorsRequest.FromString,
                    response_serializer=services_dot_stats_dot_stats__pb2.GetActorsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'social.stats.StatsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StatsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.stats.StatsService/Ping',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_common_dot_common__pb2.Pong.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Increment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.stats.StatsService/Increment',
            services_dot_stats_dot_stats__pb2.Stat.SerializeToString,
            services_dot_stats_dot_stats__pb2.IncrementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Decrement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.stats.StatsService/Decrement',
            services_dot_stats_dot_stats__pb2.Stat.SerializeToString,
            services_dot_stats_dot_stats__pb2.DecrementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Count(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.stats.StatsService/Count',
            services_dot_stats_dot_stats__pb2.Stat.SerializeToString,
            services_dot_common_dot_common__pb2.Int64Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.stats.StatsService/GetActors',
            services_dot_stats_dot_stats__pb2.GetActorsRequest.SerializeToString,
            services_dot_stats_dot_stats__pb2.GetActorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
